@@ -14,12 +14,15 @@ import pandas as pd
 
 
 class FoamCase:
-    def __init__(self, filepath, time = None, readfromfile = False):
+    def __init__(self, filepath, time = None, readfromfile = False, read_parameters = True):
         self.filepath = filepath
         self.parameters = {}
         self.postParameters = {}
         if not readfromfile:
-            self.get_parameters(time)
+            if read_parameters == True:
+                self.get_parameters(time)
+            else:
+                pass
         else:
             self.load_pffile()
 
@@ -37,10 +40,91 @@ class FoamCase:
         for i in range(0,len(c1)):
             c1[i] = c1[i][1:]
             c3[i] = c3[i][:-1]
+        try:
+            c1 = c1.astype(float)
+        except:
+            c_float = np.zerps(len(c1))
+            for d in range(0,len(c1)):
+                try:
+                    c_float[d] = float(c1[d])
+                except:
+                    c_float[d] = 0
+            c1 = c_float
+        try:
+            c2 = c2.astype(float)
+        except:
+            c_float = np.zeros(len(c2))
+            for d in range(0,len(c2)):
+                try:
+                    c_float[d] = float(c2[d])
+                except:
+                    c_float[d] = 0
+            c2 = c_float
+        try:
+            c3 = c3.astype(float)
+        except:
+            c_float = np.zerps(len(c3))
+            for d in range(0,len(c3)):
+                try:
+                    c_float[d] = float(c3[d])
+                except:
+                    c_float[d] = 0
+            c3 = c_float
+        return np.vstack((c1,c2,c3)).T
+
+    def read_tensorField(self, path):
+        '''
+        Private
+        '''
+        file = open(self.filepath+path, 'r')
+        Lines = file.readlines()
+        index = Lines.index("(\n")
+        c1 = np.loadtxt(self.filepath+path, dtype=str,usecols=0, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c2 = np.loadtxt(self.filepath+path, dtype=str,usecols=1, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c3 = np.loadtxt(self.filepath+path, dtype=str,usecols=2, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c4 = np.loadtxt(self.filepath+path, dtype=str,usecols=3, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c5 = np.loadtxt(self.filepath+path, dtype=str,usecols=4, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c6 = np.loadtxt(self.filepath+path, dtype=str,usecols=5, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c7 = np.loadtxt(self.filepath+path, dtype=str,usecols=6, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c8 = np.loadtxt(self.filepath+path, dtype=str,usecols=7, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c9 = np.loadtxt(self.filepath+path, dtype=str,usecols=8, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        for i in range(0,len(c1)):
+            c1[i] = c1[i][1:]
+            c9[i] = c9[i][:-1]
         c1 = c1.astype(float)
         c2 = c2.astype(float)
         c3 = c3.astype(float)
-        return np.vstack((c1,c2,c3)).T
+        c4 = c1.astype(float)
+        c5 = c2.astype(float)
+        c6 = c3.astype(float)
+        c7 = c1.astype(float)
+        c8 = c2.astype(float)
+        c9 = c3.astype(float)
+        return np.vstack((c1,c2,c3,c4,c5,c6,c7,c8,c9)).T
+
+    def read_symmTensorField(self, path):
+        '''
+        Private
+        '''
+        file = open(self.filepath+path, 'r')
+        Lines = file.readlines()
+        index = Lines.index("(\n")
+        c1 = np.loadtxt(self.filepath+path, dtype=str,usecols=0, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c2 = np.loadtxt(self.filepath+path, dtype=str,usecols=1, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c3 = np.loadtxt(self.filepath+path, dtype=str,usecols=2, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c4 = np.loadtxt(self.filepath+path, dtype=str,usecols=3, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c5 = np.loadtxt(self.filepath+path, dtype=str,usecols=4, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c6 = np.loadtxt(self.filepath+path, dtype=str,usecols=5, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        for i in range(0,len(c1)):
+            c1[i] = c1[i][1:]
+            c6[i] = c6[i][:-1]
+        c1 = c1.astype(float)
+        c2 = c2.astype(float)
+        c3 = c3.astype(float)
+        c4 = c1.astype(float)
+        c5 = c2.astype(float)
+        c6 = c3.astype(float)
+        return np.vstack((c1,c2,c3,c4,c5,c6)).T
 
     def read_faceList(self):
         '''
@@ -51,10 +135,10 @@ class FoamCase:
         file = open(self.filepath+path, 'r')
         Lines = file.readlines()
         index = Lines.index("(\n")
-        c1 = np.loadtxt(self.filepath+path, dtype=str,usecols=0, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
-        c2 = np.loadtxt(self.filepath+path, dtype=str,usecols=1, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
-        c3 = np.loadtxt(self.filepath+path, dtype=str,usecols=2, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
-        c4 = np.loadtxt(self.filepath+path, dtype=str,usecols=-1, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c1 = np.loadtxt(self.filepath+path, dtype='<U9',usecols=0, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c2 = np.loadtxt(self.filepath+path, dtype='<U9',usecols=1, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c3 = np.loadtxt(self.filepath+path, dtype='<U9',usecols=2, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
+        c4 = np.loadtxt(self.filepath+path, dtype='<U9',usecols=-1, skiprows=index+1, max_rows=int(Lines[index-1]), delimiter=" ")
         for i in range(0,len(c1)):
             c1[i] = c1[i][2:]
             if c4[i][-1]==')':
@@ -86,7 +170,7 @@ class FoamCase:
                                 empty = True
                             elif match[0] == 'nFaces':
                                 nFaces = match[1]
-                                if int(nFaces)>1000:
+                                if int(nFaces)>1500:
                                     empty=True
                             elif match[0] == 'startFace':
                                 startFace = match[1]
@@ -152,6 +236,12 @@ class FoamCase:
                     elif 'volScalarField' in j:
                         param = self.read_scalarField('/'+str(time)+'/'+i)
                         self.parameters[i]=param
+                    elif 'volTensorField' in j:
+                        param = self.read_tensorField('/'+str(time)+'/'+i)
+                        self.parameters[i]=param
+                    elif 'volSymmTensorField' in j:
+                        param = self.read_symmTensorField('/'+str(time)+'/'+i)
+                        self.parameters[i]=param
                     else:
                         pass
 
@@ -254,6 +344,9 @@ class FoamCase:
             else:
                 line = np.vstack((line,lines.get(next_line)))
             lines[next_line]=np.full((lines[next_line].shape[0], lines[next_line].shape[1]), np.inf)
+            #plt.plot(line[:,0],line[:,1])
+            #plt.savefig('test.png', dpi = 300, bbox_inches='tight')
+            #plt.show()
             if dx == np.inf:
                 line_completed = True 
         return line
