@@ -9,5 +9,9 @@ import numpy as np
 #pe_hills2 = fp.loadpf("peCase.pf")
 #pe_hills2.plotSurface('k', out = "surface_k.png", colorbar=True)
 
-cbfs = fp.FoamCase('/home/yiagoskyrits/OpenFOAM/yiagoskyrits-9/run/cbfs13700')
-cbfs.plotSurface('k', out='test.png')
\ No newline at end of file
+#cbfs = fp.FoamCase('/home/yiagoskyrits/OpenFOAM/yiagoskyrits-9/run/convdiv20580')
+#cbfs.plotSurface('k', out='test.png')
+
+pe_hills = fp.FoamCase("/home/yiagoskyrits/OpenFOAM/yiagoskyrits-9/run/faith_hill")
+pe_hills.show_parameters()
+
